import { EndpointParameterInstructions } from "@aws-sdk/middleware-endpoint";
import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { EC2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../EC2Client";
import { GetIpamResourceCidrsRequest, GetIpamResourceCidrsResult } from "../models/models_5";
/**
 * @public
 *
 * The input for {@link GetIpamResourceCidrsCommand}.
 */
export interface GetIpamResourceCidrsCommandInput extends GetIpamResourceCidrsRequest {
}
/**
 * @public
 *
 * The output of {@link GetIpamResourceCidrsCommand}.
 */
export interface GetIpamResourceCidrsCommandOutput extends GetIpamResourceCidrsResult, __MetadataBearer {
}
/**
 * @public
 * <p>Returns resource CIDRs managed by IPAM in a given scope. If an IPAM is associated with more than one resource discovery, the resource CIDRs across all of the resource discoveries is returned. A resource discovery is an IPAM component that enables IPAM to manage and monitor resources that belong to the owning account.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { EC2Client, GetIpamResourceCidrsCommand } from "@aws-sdk/client-ec2"; // ES Modules import
 * // const { EC2Client, GetIpamResourceCidrsCommand } = require("@aws-sdk/client-ec2"); // CommonJS import
 * const client = new EC2Client(config);
 * const input = { // GetIpamResourceCidrsRequest
 *   DryRun: true || false,
 *   Filters: [ // FilterList
 *     { // Filter
 *       Name: "STRING_VALUE",
 *       Values: [ // ValueStringList
 *         "STRING_VALUE",
 *       ],
 *     },
 *   ],
 *   MaxResults: Number("int"),
 *   NextToken: "STRING_VALUE",
 *   IpamScopeId: "STRING_VALUE", // required
 *   IpamPoolId: "STRING_VALUE",
 *   ResourceId: "STRING_VALUE",
 *   ResourceType: "vpc" || "subnet" || "eip" || "public-ipv4-pool" || "ipv6-pool",
 *   ResourceTag: { // RequestIpamResourceTag
 *     Key: "STRING_VALUE",
 *     Value: "STRING_VALUE",
 *   },
 *   ResourceOwner: "STRING_VALUE",
 * };
 * const command = new GetIpamResourceCidrsCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @param GetIpamResourceCidrsCommandInput - {@link GetIpamResourceCidrsCommandInput}
 * @returns {@link GetIpamResourceCidrsCommandOutput}
 * @see {@link GetIpamResourceCidrsCommandInput} for command's `input` shape.
 * @see {@link GetIpamResourceCidrsCommandOutput} for command's `response` shape.
 * @see {@link EC2ClientResolvedConfig | config} for EC2Client's `config` shape.
 *
 *
 */
export declare class GetIpamResourceCidrsCommand extends $Command<GetIpamResourceCidrsCommandInput, GetIpamResourceCidrsCommandOutput, EC2ClientResolvedConfig> {
    readonly input: GetIpamResourceCidrsCommandInput;
    static getEndpointParameterInstructions(): EndpointParameterInstructions;
    /**
     * @public
     */
    constructor(input: GetIpamResourceCidrsCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: EC2ClientResolvedConfig, options?: __HttpHandlerOptions): Handler<GetIpamResourceCidrsCommandInput, GetIpamResourceCidrsCommandOutput>;
    /**
     * @internal
     */
    private serialize;
    /**
     * @internal
     */
    private deserialize;
}
